// Swarm library.
// Copyright (C) 1996  by the Regents of the University of Michigan.
// This library is distributed without any warranty; without even the
// implied warranty of merchantability or fitness for a particular purpose.
// See file LICENSE for details and terms of copying.

// object to shuffle Swarm List list with num elts, in place
// from Knuth vol 2

#import <objectbase/SwarmObject.h>
#import <random.h>

@interface Shuffler: SwarmObject
{
  id <UniformInteger> uniformRandom;
}

- setUniformRandom: rnd;
- createEnd;
- shuffleList: list;

@end


